BitStructExt

Trait BitStructExt 

pub trait BitStructExt: BitStruct<true> {
    // Required method
    fn exact_from(value: Self::Kind) -> Self;
}
An extension trait for bit structs which can be safely made from any value in their underlying storage type.

Required Methods

fn exact_from(value: Self::Kind) -> Self

Produce a bit struct from the given underlying storage

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: BitStruct<true>> BitStructExt for T