pub trait BitStructExt: BitStruct<true> {
// Required method
fn exact_from(value: Self::Kind) -> Self;
}Expand description
An extension trait for bit structs which can be safely made from any value in their underlying storage type.
Required Methods
Sourcefn exact_from(value: Self::Kind) -> Self
fn exact_from(value: Self::Kind) -> Self
Produce a bit struct from the given underlying storage
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".